@@ -10,7 +10,7 @@ R = t.TypeVar('R', bound=t.Union[AbstractSyncRepository, AbstractAsyncRepository
 
 class AbstractUnitOfWork(t.Generic[R]):
 
-    def __init__(self, engine: t.Any, repository_class: t.Type[R]):
+    def __init__(self, engine: t.Any, repository_class):
         self._engine = engine
         self._events: t.Set[DDDEvent] = set()
         self._current_transaction_events: t.Set[DDDEvent] = set()
@@ -63,7 +63,7 @@ class AbstractUnitOfWork(t.Generic[R]):
         self._in_context = False
 
 
-class AbstractAsyncUnitOfWork(AbstractUnitOfWork):
+class AbstractAsyncUnitOfWork(AbstractUnitOfWork, t.Generic[R]):
 
     @t.final
     async def __aenter__(self):
@@ -100,7 +100,7 @@ class AbstractAsyncUnitOfWork(AbstractUnitOfWork):
         ...
 
 
-class AbstractSyncUnitOfWork(AbstractUnitOfWork[R]):
+class AbstractSyncUnitOfWork(AbstractUnitOfWork[R], t.Generic[R]):
 
     @t.final
     def __enter__(self):
